==> jc-1.4.0.tar.gz: java/io/FilePermission.h <==
// public final class java.io.FilePermission

// class file dependencies
// @dep_class 314b87573a912ae6 java_io_FilePermission
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 2377c76e79058a72 java_security_Permission

// header file dependencies
// @dep_header java_security_Permission

#include "java/security/Permission.h"

#ifndef _JC_java_io_FilePermission_H_
#define _JC_java_io_FilePermission_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_java_security_Permission$object;

// Typedefs
typedef struct _jc_java_io_FilePermission$sub_refs	_jc_java_io_FilePermission$sub_refs;
typedef struct _jc_java_io_FilePermission$sub_nonrefs	_jc_java_io_FilePermission$sub_nonrefs;
typedef struct _jc_java_io_FilePermission$refs	_jc_java_io_FilePermission$refs;
typedef struct _jc_java_io_FilePermission$nonrefs	_jc_java_io_FilePermission$nonrefs;
typedef struct _jc_java_io_FilePermission$object	_jc_java_io_FilePermission$object;

typedef struct _jc_java_io_FilePermission$fields_struct	_jc_java_io_FilePermission$fields_struct;
typedef const struct _jc_java_io_FilePermission$vmethods	_jc_java_io_FilePermission$vmethods;
typedef const struct _jc_java_io_FilePermission$vtable	_jc_java_io_FilePermission$vtable;
typedef const struct _jc_java_io_FilePermission$vtype	_jc_java_io_FilePermission$vtype;

// Class fields structure
struct _jc_java_io_FilePermission$fields_struct {
	struct _jc_java_lang_String$object	*CURRENT__5fDIRECTORY;
	jlong	serialVersionUID;
};
extern _jc_java_io_FilePermission$fields_struct _jc_java_io_FilePermission$class_fields;

// Constructors
extern void _jc_java_io_FilePermission$method$_init$a34354cd9552963f(_jc_env *, struct _jc_java_io_FilePermission$object *, struct _jc_java_lang_String$object *, struct _jc_java_lang_String$object *);

// Virtual methods
extern void _jc_java_io_FilePermission$method$checkPerms$163750487c2d90ab(_jc_env *, struct _jc_java_io_FilePermission$object *);
extern jboolean _jc_java_io_FilePermission$method$equals$8a15e0625571c581(_jc_env *, struct _jc_java_io_FilePermission$object *, struct _jc_java_lang_Object$object *);
extern struct _jc_java_lang_String$object *_jc_java_io_FilePermission$method$getActions$a96d1cd349ac27ec(_jc_env *, struct _jc_java_io_FilePermission$object *);
extern jint _jc_java_io_FilePermission$method$hashCode$53152098849316df(_jc_env *, struct _jc_java_io_FilePermission$object *);
extern jboolean _jc_java_io_FilePermission$method$implies$cbacf9d54b2bb917(_jc_env *, struct _jc_java_io_FilePermission$object *, struct _jc_java_security_Permission$object *);
extern void _jc_java_io_FilePermission$method$this$adc93fb6bf4cbffa(_jc_env *, struct _jc_java_io_FilePermission$object *);

// Virtual method descriptors
extern _jc_method _jc_java_io_FilePermission$method_info$checkPerms$163750487c2d90ab;
extern _jc_method _jc_java_io_FilePermission$method_info$equals$8a15e0625571c581;
extern _jc_method _jc_java_io_FilePermission$method_info$getActions$a96d1cd349ac27ec;
extern _jc_method _jc_java_io_FilePermission$method_info$hashCode$53152098849316df;
extern _jc_method _jc_java_io_FilePermission$method_info$implies$cbacf9d54b2bb917;
extern _jc_method _jc_java_io_FilePermission$method_info$this$adc93fb6bf4cbffa;

// Static methods
extern void _jc_java_io_FilePermission$method$_clinit$a816641e0ba8bfef(_jc_env *);

// Virtual methods structure
struct _jc_java_io_FilePermission$vmethods {
	void	(*checkPerms$163750487c2d90ab)(_jc_env *, struct _jc_java_io_FilePermission$object *);
	jboolean	(*equals$8a15e0625571c581)(_jc_env *, struct _jc_java_io_FilePermission$object *, struct _jc_java_lang_Object$object *);
	struct _jc_java_lang_String$object	*(*getActions$a96d1cd349ac27ec)(_jc_env *, struct _jc_java_io_FilePermission$object *);
	jint	(*hashCode$53152098849316df)(_jc_env *, struct _jc_java_io_FilePermission$object *);
	jboolean	(*implies$cbacf9d54b2bb917)(_jc_env *, struct _jc_java_io_FilePermission$object *, struct _jc_java_security_Permission$object *);
	void	(*this$adc93fb6bf4cbffa)(_jc_env *, struct _jc_java_io_FilePermission$object *);
};

// Vtable
struct _jc_java_io_FilePermission$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_security_Permission$vmethods	java_security_Permission;
	_jc_java_io_FilePermission$vmethods	java_io_FilePermission;
};

// Vtype
struct _jc_java_io_FilePermission$vtype {
	_jc_type			type;
	_jc_java_io_FilePermission$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_io_FilePermission$sub_refs {
	struct _jc_java_lang_String$object	*actionsString;
};

// Reference instance fields (object)
struct _jc_java_io_FilePermission$refs {
    _jc_java_io_FilePermission$sub_refs	java_io_FilePermission;
    _jc_java_security_Permission$sub_refs	java_security_Permission;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_io_FilePermission$sub_nonrefs {
	jboolean	readPerm;
	jboolean	writePerm;
	jboolean	executePerm;
	jboolean	deletePerm;
};

// Non-reference instance fields (object)
struct _jc_java_io_FilePermission$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_security_Permission$sub_nonrefs	java_security_Permission;
    _jc_java_io_FilePermission$sub_nonrefs	java_io_FilePermission;
};

// Object instance structure
struct _jc_java_io_FilePermission$object {
	_jc_java_io_FilePermission$refs	refs[0];
	_jc_word		lockword;
	_jc_java_io_FilePermission$vtype	*vtype;
	_jc_java_io_FilePermission$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_io_FilePermission$vtype _jc_java_io_FilePermission$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_io_FilePermission, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_io_FilePermission$class_object;

#endif	/* _JC_java_io_FilePermission_H_ */

==> jc-1.4.6.tar.gz: java/io/FilePermission.h <==
// public final class java.io.FilePermission

// class file dependencies
// @dep_class 557435d985e351f7 java_io_FilePermission
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 2377c76e79058a72 java_security_Permission

// header file dependencies
// @dep_header java_security_Permission

#include "java/security/Permission.h"

#ifndef _JC_java_io_FilePermission_H_
#define _JC_java_io_FilePermission_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_java_security_Permission$object;

// Typedefs
typedef struct _jc_java_io_FilePermission$sub_refs	_jc_java_io_FilePermission$sub_refs;
typedef struct _jc_java_io_FilePermission$sub_nonrefs	_jc_java_io_FilePermission$sub_nonrefs;
typedef struct _jc_java_io_FilePermission$refs	_jc_java_io_FilePermission$refs;
typedef struct _jc_java_io_FilePermission$nonrefs	_jc_java_io_FilePermission$nonrefs;
typedef struct _jc_java_io_FilePermission$object	_jc_java_io_FilePermission$object;

typedef struct _jc_java_io_FilePermission$fields_struct	_jc_java_io_FilePermission$fields_struct;
typedef const struct _jc_java_io_FilePermission$vmethods	_jc_java_io_FilePermission$vmethods;
typedef const struct _jc_java_io_FilePermission$vtable	_jc_java_io_FilePermission$vtable;
typedef const struct _jc_java_io_FilePermission$vtype	_jc_java_io_FilePermission$vtype;

// Class fields structure
struct _jc_java_io_FilePermission$fields_struct {
	struct _jc_java_lang_String$object	*ALL__5fFILES;
	struct _jc_java_lang_String$object	*CURRENT__5fDIRECTORY;
	jlong	serialVersionUID;
};
extern _jc_java_io_FilePermission$fields_struct _jc_java_io_FilePermission$class_fields;

// Constructors
extern void _jc_java_io_FilePermission$method$_init$a34354cd9552963f(_jc_env *, struct _jc_java_io_FilePermission$object *, struct _jc_java_lang_String$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_java_io_FilePermission$method$checkPerms$163750487c2d90ab(_jc_env *, struct _jc_java_io_FilePermission$object *) _JC_JCNI_ATTR;
extern jboolean _jc_java_io_FilePermission$method$equals$8a15e0625571c581(_jc_env *, struct _jc_java_io_FilePermission$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_java_io_FilePermission$method$getActions$a96d1cd349ac27ec(_jc_env *, struct _jc_java_io_FilePermission$object *) _JC_JCNI_ATTR;
extern jint _jc_java_io_FilePermission$method$hashCode$53152098849316df(_jc_env *, struct _jc_java_io_FilePermission$object *) _JC_JCNI_ATTR;
extern jboolean _jc_java_io_FilePermission$method$implies$cbacf9d54b2bb917(_jc_env *, struct _jc_java_io_FilePermission$object *, struct _jc_java_security_Permission$object *) _JC_JCNI_ATTR;
extern void _jc_java_io_FilePermission$method$this$adc93fb6bf4cbffa(_jc_env *, struct _jc_java_io_FilePermission$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_java_io_FilePermission$method_info$checkPerms$163750487c2d90ab;
extern _jc_method _jc_java_io_FilePermission$method_info$equals$8a15e0625571c581;
extern _jc_method _jc_java_io_FilePermission$method_info$getActions$a96d1cd349ac27ec;
extern _jc_method _jc_java_io_FilePermission$method_info$hashCode$53152098849316df;
extern _jc_method _jc_java_io_FilePermission$method_info$implies$cbacf9d54b2bb917;
extern _jc_method _jc_java_io_FilePermission$method_info$this$adc93fb6bf4cbffa;

// Static methods
extern void _jc_java_io_FilePermission$method$_clinit$a816641e0ba8bfef(_jc_env *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_java_io_FilePermission$vmethods {
	void	(*checkPerms$163750487c2d90ab)(_jc_env *, struct _jc_java_io_FilePermission$object *) _JC_JCNI_ATTR;
	jboolean	(*equals$8a15e0625571c581)(_jc_env *, struct _jc_java_io_FilePermission$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*getActions$a96d1cd349ac27ec)(_jc_env *, struct _jc_java_io_FilePermission$object *) _JC_JCNI_ATTR;
	jint	(*hashCode$53152098849316df)(_jc_env *, struct _jc_java_io_FilePermission$object *) _JC_JCNI_ATTR;
	jboolean	(*implies$cbacf9d54b2bb917)(_jc_env *, struct _jc_java_io_FilePermission$object *, struct _jc_java_security_Permission$object *) _JC_JCNI_ATTR;
	void	(*this$adc93fb6bf4cbffa)(_jc_env *, struct _jc_java_io_FilePermission$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_java_io_FilePermission$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_security_Permission$vmethods	java_security_Permission;
	_jc_java_io_FilePermission$vmethods	java_io_FilePermission;
};

// Vtype
struct _jc_java_io_FilePermission$vtype {
	_jc_type			type;
	_jc_java_io_FilePermission$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_io_FilePermission$sub_refs {
	struct _jc_java_lang_String$object	*actionsString;
};

// Reference instance fields (object)
struct _jc_java_io_FilePermission$refs {
    _jc_java_io_FilePermission$sub_refs	java_io_FilePermission;
    _jc_java_security_Permission$sub_refs	java_security_Permission;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_io_FilePermission$sub_nonrefs {
	jboolean	readPerm;
	jboolean	writePerm;
	jboolean	executePerm;
	jboolean	deletePerm;
};

// Non-reference instance fields (object)
struct _jc_java_io_FilePermission$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_security_Permission$sub_nonrefs	java_security_Permission;
    _jc_java_io_FilePermission$sub_nonrefs	java_io_FilePermission;
};

// Object instance structure
struct _jc_java_io_FilePermission$object {
	_jc_java_io_FilePermission$refs	refs[0];
	_jc_word		lockword;
	_jc_java_io_FilePermission$vtype	*vtype;
	_jc_java_io_FilePermission$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_io_FilePermission$vtype _jc_java_io_FilePermission$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_io_FilePermission, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_io_FilePermission$class_object;

#endif	/* _JC_java_io_FilePermission_H_ */
